/*
 *  TOPPERS/ASP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Advanced Standard Profile Kernel
 *
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *  Copyright (C) 2004-2010 by Embedded and Real-Time Systems Laboratory
 *              Graduate School of Information Science, Nagoya Univ., JAPAN
 *  Copyright (C) 2015-2017 by TOPPERS PROJECT Educational Working Group.
 *
 *  嵭Ԥϡʲ(1)(4)ξ˸¤ꡤܥեȥ
 *  ܥեȥѤΤޤࡥʲƱˤѡʣ
 *  ѡۡʰʲѤȸƤ֡ˤ뤳Ȥ̵ǵ롥
 *  (1) ܥեȥ򥽡ɤηѤˤϡ嵭
 *      ɽѾ浪Ӳ̵ݾڵ꤬Τޤޤηǥ
 *      ˴ޤޤƤ뤳ȡ
 *  (2) ܥեȥ򡤥饤֥ʤɡ¾Υեȥȯ˻
 *      ѤǤǺۤˤϡۤȼɥȡ
 *      ԥޥ˥奢ʤɡˤˡ嵭ɽѾ浪Ӳ
 *      ̵ݾڵǺܤ뤳ȡ
 *  (3) ܥեȥ򡤵Ȥ߹ʤɡ¾Υեȥȯ˻
 *      ѤǤʤǺۤˤϡΤ줫ξ
 *      ȡ
 *    (a) ۤȼɥȡѼԥޥ˥奢ʤɡˤˡ嵭
 *        ɽѾ浪Ӳ̵ݾڵǺܤ뤳ȡ
 *    (b) ۤη֤̤ˡˤäơTOPPERSץȤ
 *        𤹤뤳ȡ
 *  (4) ܥեȥѤˤľŪޤϴŪ뤤ʤ»
 *      ⡤嵭ԤTOPPERSץȤդ뤳ȡ
 *      ޤܥեȥΥ桼ޤϥɥ桼Τʤ
 *      ͳ˴Ťᤫ⡤嵭ԤTOPPERSץȤ
 *      դ뤳ȡ
 * 
 *  ܥեȥϡ̵ݾڤ󶡤ƤΤǤ롥嵭Ԥ
 *  TOPPERSץȤϡܥեȥ˴ؤơλŪ
 *  ФŬޤơʤݾڤԤʤޤܥեȥ
 *  ѤˤľŪޤϴŪʤ»˴ؤƤ⡤
 *  Ǥʤ
 *
 *  $Id: x_nucleo_iks01a1.h 2416 2017-12-26 14:32:08Z roi $
 */
/**
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2017 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/*
 *  X-NUCLEO-IKS01A1 DRIVERΥإåե
 */

#ifndef _X_NUCLEO_IKS01A1_DRIVER_H_
#define _X_NUCLEO_IKS01A1_DRIVER_H_

#include <kernel.h>
#include <t_syslog.h>
#include <t_stdlib.h>
#include "syssvc/serial.h"
#include "syssvc/syslog.h"

#include "accelerometer.h"
#include "gyroscope.h"
#include "magnetometer.h"
#include "humidity.h"
#include "temperature.h"
#include "pressure.h"

#ifdef __cplusplus
 extern "C" {
#endif

#define IKS01A1_HTS221_WHO_AM_I  (uint8_t)0xBC
#define IKS01A1_LPS25HB_WHO_AM_I (uint8_t)0xBD
#define IKS01A1_LPS22HB_WHO_AM_I (uint8_t)0xB1
#define IKS01A1_LSM6DS0_WHO_AM_I (uint8_t)0x68
#define IKS01A1_LSM6DS3_WHO_AM_I (uint8_t)0x69
#define IKS01A1_LIS3MDL_WHO_AM_I (uint8_t)0x3D

#ifndef TOPPERS_MACRO_ONLY

/*
 *  BLUENRGϥɥ鹽¤
 */
typedef struct SENSOR_I2C_Handle SENSOR_I2C_Handle_t;
struct SENSOR_I2C_Handle {
	void    *i2c_handle;
	ER      (*si2c_init)(SENSOR_I2C_Handle_t *hsi2c);
	ER      (*si2c_write)(SENSOR_I2C_Handle_t *hsi2c, uint8_t Addr, uint8_t Reg, uint8_t* pBuffer, uint16_t Size);
	ER      (*si2c_read)(SENSOR_I2C_Handle_t *hsi2c, uint8_t Addr, uint8_t Reg, uint8_t* pBuffer, uint16_t Size);
	void    (*si2c_setint)(SENSOR_I2C_Handle_t *hsi2c, uint8_t no);
};

#define HAL_Delay dly_tsk

/*
 *  ؿΥץȥ
 */
extern void Sensor_Drv_Setup(SENSOR_I2C_Handle_t *hsi2c);
extern DrvStatusTypeDef Sensor_IO_Init( void );
extern DrvStatusTypeDef LSM6DS0_Sensor_IO_ITConfig( void );
extern DrvStatusTypeDef LSM6DS3_Sensor_IO_ITConfig( void );
extern DrvStatusTypeDef LPS22HB_Sensor_IO_ITConfig( void );


#endif /* TOPPERS_MACRO_ONLY */

#ifdef __cplusplus
}
#endif

#endif	/* _X_NUCLEO_IKS01A1_DRIVER_H_ */

